[−][src]Struct erasable::Thin

pub struct Thin<P: ErasablePtr> { /* fields omitted */ }

Wrapper struct to create thin pointer types.

Methods

impl<P: ErasablePtr> Thin<P>[src]

pub fn into_inner(this: Self) -> P[src]

Extract the wrapped pointer.

pub fn with<F, T>(this: &Self, f: F) -> T where
    F: FnOnce(&P) -> T, 
[src]

Run a closure with a borrow of the real pointer.

pub fn with_mut<F, T>(this: &mut Self, f: F) -> T where
    F: FnOnce(&mut P) -> T, 
[src]

Run a closure with a mutable borrow of the real pointer.